==> jvxall-2.0-sources.jar: javax/rad/remote/CommunicationException.java <==
/*
 * Copyright 2009 SIB Visions GmbH
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 *
 *
 * History
 *
 * 12.08.2009 - [JR] - creation
 */
package javax.rad.remote;

/**
 * The <code>CommunicationException</code> is a {@link RuntimeException} for 
 * client/server communication problems.
 * 
 * @author Ren Jahn
 */
public class CommunicationException extends RuntimeException
{
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	// Initialization
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

	/** 
	 * Constructs a new <code>CommunicationException</code> with <code>null</code> as its
     * detail message. The cause is not initialized, and may subsequently be initialized by 
     * a call to {@link #initCause}.
     */
	public CommunicationException()
	{
		super();
	}

	/** 
	 * Constructs a new <code>CommunicationException</code> with the specified cause and a
     * detail message of <tt>(cause==null ? null : cause.toString())</tt>
     * (which typically contains the class and detail message of
     * <tt>cause</tt>).
     *
     * @param pCause the cause (which is saved for later retrieval by the
     *               {@link #getCause()} method).  (A <tt>null</tt> value is
     *               permitted, and indicates that the cause is nonexistent or
     *               unknown.)
     */
	public CommunicationException(Throwable pCause)
	{
		super(pCause);
	}
	
    /** 
     * Constructs a new <code>CommunicationException</code> with the specified detail message.
     * The cause is not initialized, and may subsequently be initialized by a call to 
     * {@link #initCause}.
     *
     * @param pMessage the detail message. The detail message is saved for 
     *                 later retrieval by the {@link #getMessage()} method.
     */
	public CommunicationException(String pMessage)
	{
		super(pMessage);
	}
	
    /**
     * Constructs a new <code>CommunicationException</code> with the specified detail message and
     * cause. <p>Note that the detail message associated with
     * <code>cause</code> is <i>not</i> automatically incorporated in
     * this exception's detail message.
     *
     * @param pMessage the detail message (which is saved for later retrieval
     *        by the {@link #getMessage()} method).
     * @param pCause the cause (which is saved for later retrieval by the
     *        {@link #getCause()} method).  (A <tt>null</tt> value is
     *        permitted, and indicates that the cause is nonexistent or
     *        unknown.)
     */
	public CommunicationException(String pMessage, Throwable pCause)
	{
		super(pMessage, pCause);
	}
	
}	// CommunicationException

==> jvxall-2.1-sources.jar: javax/rad/remote/CommunicationException.java <==
/*
 * Copyright 2009 SIB Visions GmbH
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 *
 *
 * History
 *
 * 12.08.2009 - [JR] - creation
 */
package javax.rad.remote;

/**
 * The <code>CommunicationException</code> is a {@link RuntimeException} for 
 * client/server communication problems.
 * 
 * @author Ren Jahn
 */
public class CommunicationException extends RuntimeException
{
    //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    // User-defined methods
    //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

    /** the connection, if known. */
    private AbstractConnection connection;
        
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	// Initialization
	//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

	/** 
	 * Constructs a new <code>CommunicationException</code> with <code>null</code> as its
     * detail message. The cause is not initialized, and may subsequently be initialized by 
     * a call to {@link #initCause}.
     */
	public CommunicationException()
	{
		super();
	}

	/** 
	 * Constructs a new <code>CommunicationException</code> with the specified cause and a
     * detail message of <tt>(cause==null ? null : cause.toString())</tt>
     * (which typically contains the class and detail message of
     * <tt>cause</tt>).
     *
     * @param pCause the cause (which is saved for later retrieval by the
     *               {@link #getCause()} method).  (A <tt>null</tt> value is
     *               permitted, and indicates that the cause is nonexistent or
     *               unknown.)
     */
	public CommunicationException(Throwable pCause)
	{
		super(pCause);
	}
	
    /** 
     * Constructs a new <code>CommunicationException</code> with the specified detail message.
     * The cause is not initialized, and may subsequently be initialized by a call to 
     * {@link #initCause}.
     *
     * @param pMessage the detail message. The detail message is saved for 
     *                 later retrieval by the {@link #getMessage()} method.
     */
	public CommunicationException(String pMessage)
	{
		super(pMessage);
	}
	
    /**
     * Constructs a new <code>CommunicationException</code> with the specified detail message and
     * cause. <p>Note that the detail message associated with
     * <code>cause</code> is <i>not</i> automatically incorporated in
     * this exception's detail message.
     *
     * @param pMessage the detail message (which is saved for later retrieval
     *        by the {@link #getMessage()} method).
     * @param pCause the cause (which is saved for later retrieval by the
     *        {@link #getCause()} method).  (A <tt>null</tt> value is
     *        permitted, and indicates that the cause is nonexistent or
     *        unknown.)
     */
	public CommunicationException(String pMessage, Throwable pCause)
	{
		super(pMessage, pCause);
	}
	
    //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    // User-defined methods
    //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
    
    /**
     * Sets the connection which received the exception.
     * 
     * @param pConnection the Exception receiver
     */
    public void setConnection(AbstractConnection pConnection)
    {
        connection = pConnection;
    }
    
    /**
     * Gets the connection which received the exception.
     * 
     * @return the Exception receiver or <code>null</code> if Exception wasn't caught by an 
     *         {@link AbstractConnection} 
     */
    public AbstractConnection getConnection()
    {
        return connection;
    }	
	
}	// CommunicationException
